@@ -74,8 +74,9 @@ class LanguagesAdminPage(pagelayout.PootlePage):
     templatename = "adminlanguages"
     sessionvars = {"status": self.session.status, "isopen": self.session.isopen, "issiteadmin": self.session.issiteadmin()}
     instancetitle = getattr(self.instance, "title", session.localize("Pootle Demo"))
+    pagetitle = self.localize("Pootle Languages Admin Page")
     text = self.gettext(session)
-    templatevars = {"languages": self.getlanguagesoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
+    templatevars = {"pagetitle": pagetitle, "languages": self.getlanguagesoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
     pagelayout.PootlePage.__init__(self, templatename, templatevars, session)
 
   def gettext(self, session):
@@ -132,8 +133,9 @@ class ProjectsAdminPage(pagelayout.PootlePage):
     self.alltypes = [{"value": check, "description": check} for check in projectfiletypes]
     sessionvars = {"status": self.session.status, "isopen": self.session.isopen, "issiteadmin": self.session.issiteadmin()}
     instancetitle = getattr(self.instance, "title", session.localize("Pootle Demo"))
+    pagetitle = self.localize("Pootle Projects Admin Page")
     text = self.gettext(session)
-    templatevars = {"projects": self.getprojectsoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
+    templatevars = {"pagetitle": pagetitle, "projects": self.getprojectsoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
     pagelayout.PootlePage.__init__(self, templatename, templatevars, session)
 
   def gettext(self, session):
@@ -197,8 +199,9 @@ class UsersAdminPage(pagelayout.PootlePage):
     templatename = "adminusers"
     sessionvars = {"status": self.session.status, "isopen": self.session.isopen, "issiteadmin": self.session.issiteadmin()}
     instancetitle = getattr(self.instance, "title", session.localize("Pootle Demo"))
+    pagetitle = self.localize("Pootle User Admin Page")
     text = self.gettext(session)
-    templatevars = {"users": self.getusersoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
+    templatevars = {"pagetitle": pagetitle, "users": self.getusersoptions(), "options": self.getoptions(), "session": sessionvars, "instancetitle": instancetitle, "text": text}
     pagelayout.PootlePage.__init__(self, templatename, templatevars, session)
 
   def gettext(self, session):
@@ -211,7 +214,7 @@ class UsersAdminPage(pagelayout.PootlePage):
     return text
     
   def getoptions(self):
-    options = [{"name": "name", "title": self.localize("Login"), "newvalue": "", "size": 6},
+    options = [{"name": "name", "title": self.localize("Username"), "newvalue": "", "size": 6},
                {"name": "fullname", "title": self.localize("Full Name"), 
                                     "newvalue": self.localize("(add full name here)")},
                {"name": "email", "title": self.localize("Email Address"), "newvalue": self.localize("(add email here)")},
@@ -280,6 +283,8 @@ class ProjectAdminPage(pagelayout.PootlePage):
     update_button = self.localize("Update Languages")
     pagetitle = self.localize("Pootle Admin: %s", projectname)
     norights_text = self.localize("You do not have the rights to administer this project.")
+    iso_code = self.localize("ISO Code")
+    full_name = self.localize("Full Name")
     # l10n: This refers to updating the translation files from the templates like with .pot files
     update_link = self.localize("Update from templates")
     templatename = "projectadmin"
@@ -287,6 +292,7 @@ class ProjectAdminPage(pagelayout.PootlePage):
     instancetitle = getattr(self.session.instance, "title", session.localize("Pootle Demo"))
     templatevars = {"pagetitle": pagetitle, "norights_text": norights_text,
         "project": {"code": projectcode, "name": projectname},
+        "iso_code": iso_code, "full_name": full_name,
         "existing_title": existing_title, "existing_languages": existing_languages,
         "new_languages": new_languages,
         "update_button": update_button, "add_button": self.localize("Add Language"),
