@@ -220,17 +220,22 @@ function writespecial(specialchar, elementnumber)
 
 function insertatposition(element, text, rollback) 
 {
-	var wholetext = element.value;
-	var cursorposition = element.selectionStart;
-	var finalposition = cursorposition + text.length - rollback;
+	element.focus();
+	if (navigator && navigator.appName == "Microsoft Internet Explorer")
+	{
+		document.selection.createRange().text = text;
+	}
+	else
+	{
+		var wholetext = element.value;
+		var cursorposition = element.selectionStart;
+		var finalposition = cursorposition + text.length - rollback;
 
-	var before = wholetext.substr(0, cursorposition);
-	var after = wholetext.substr(cursorposition, wholetext.length);
+		var before = wholetext.substr(0, cursorposition);
+		var after = wholetext.substr(cursorposition, wholetext.length);
 	
-	if (before != after) { //check that the browser got it right
 		element.value = before + text + after;
 		element.setSelectionRange(finalposition, finalposition);
 	}
-	element.focus();
 }
 
