@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# 
+#
 # Copyright 2004-2007 Zuza Software Foundation
-# 
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -37,15 +37,16 @@ import os
 import sys
 import re
 import locale
+import util  
 
 def shortdescription(descr):
-  """Returns a short description by removing markup and only including up 
+  """Returns a short description by removing markup and only including up
   to the first br-tag"""
   stopsign = descr.find("<br")
   if stopsign >= 0:
     descr = descr[:stopsign]
   return re.sub("<[^>]*>", "", descr).strip()
-  
+
 class AboutPage(pagelayout.PootlePage):
   """the bar at the side describing current login details etc"""
   def __init__(self, session):
@@ -53,7 +54,7 @@ class AboutPage(pagelayout.PootlePage):
     pagetitle = getattr(session.instance, "title")
     description = getattr(session.instance, "description")
     meta_description = shortdescription(description)
-    keywords = ["Pootle", "WordForge", "translate", "translation", "localisation",
+    keywords = ["Pootle", "locamotion", "translate", "translation", "localisation",
                 "localization", "l10n", "traduction", "traduire"]
     abouttitle = self.localize("About Pootle")
     # l10n: Take care to use HTML tags correctly. A markup error could cause a display error.
@@ -77,7 +78,7 @@ class AboutPage(pagelayout.PootlePage):
     pagelayout.PootlePage.__init__(self, templatename, templatevars, session)
 
 class PootleIndex(pagelayout.PootlePage):
-  """The main page listing projects and languages. It is also reused for 
+  """The main page listing projects and languages. It is also reused for
   LanguagesIndex and ProjectsIndex"""
   def __init__(self, potree, session):
     self.potree = potree
@@ -101,7 +102,7 @@ class PootleIndex(pagelayout.PootlePage):
     languages.sort(lambda x,y: locale.strcoll(x["name"], y["name"]))
     if languages:
       languages[-1]["sep"] = ""
-    templatevars = {"pagetitle": pagetitle, "description": description, 
+    templatevars = {"pagetitle": pagetitle, "description": description,
         "meta_description": meta_description, "keywords": keywords,
         "languagelink": languagelink, "languages": languages,
         "projectlink": projectlink, "projects": self.getprojects(),
@@ -141,7 +142,7 @@ class UserIndex(pagelayout.PootlePage):
     quicklinks = self.getquicklinks()
     setoptionstext = self.localize("Please click on 'Change options' and select some languages and projects")
     templatevars = {"pagetitle": pagetitle, "optionslink": optionslink,
-        "adminlink": adminlink, "admintext": admintext, 
+        "adminlink": adminlink, "admintext": admintext,
         "quicklinkstitle": quicklinkstitle,
         "quicklinks": quicklinks, "setoptionstext": setoptionstext,
         "session": sessionvars, "instancetitle": instancetitle}
@@ -161,7 +162,7 @@ class UserIndex(pagelayout.PootlePage):
           project = self.potree.getproject(languagecode, projectcode)
           isprojectadmin = "admin" in project.getrights(session=self.session) \
                             or self.session.issiteadmin()
-          langlinks.append({"code": projectcode, "name": projecttitle, 
+          langlinks.append({"code": projectcode, "name": projecttitle,
                             "isprojectadmin": isprojectadmin, "sep": "<br />"})
       if langlinks:
         langlinks[-1]["sep"] = ""
@@ -208,7 +209,7 @@ class LanguageIndex(pagelayout.PootleNavPage):
     sessionvars = {"status": session.status, "isopen": session.isopen, "issiteadmin": session.issiteadmin()}
     templatevars = {"pagetitle": pagetitle,
         "language": {"code": languagecode, "name": self.tr_lang(self.languagename), "stats": languagestats, "info": languageinfo},
-        "projects": languageprojects, 
+        "projects": languageprojects,
         "statsheadings": self.getstatsheadings(),
         "session": sessionvars, "instancetitle": instancetitle}
     pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
@@ -240,7 +241,6 @@ class LanguageIndex(pagelayout.PootleNavPage):
     projectname = self.potree.getprojectname(projectcode)
     projectdescription = shortdescription(self.potree.getprojectdescription(projectcode))
     project = self.potree.getproject(self.languagecode, projectcode)
-    pofilenames = project.browsefiles()
     projectstats = project.getquickstats()
     projectdata = self.getstats(project, projectstats)
     self.updatepagestats(projectdata["translatedsourcewords"], projectdata["totalsourcewords"])
@@ -273,9 +273,9 @@ class ProjectLanguageIndex(pagelayout.PootleNavPage):
     statsheadings["name"] = self.localize("Language")
     templatevars = {"pagetitle": pagetitle,
         "project": {"code": projectcode, "name": projectname, "stats": projectstats},
-        "description": description, "meta_description": meta_description, 
+        "description": description, "meta_description": meta_description,
         "adminlink": adminlink, "languages": languages,
-        "session": sessionvars, "instancetitle": instancetitle, 
+        "session": sessionvars, "instancetitle": instancetitle,
         "statsheadings": statsheadings}
     pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
 
@@ -299,6 +299,29 @@ class ProjectLanguageIndex(pagelayout.PootleNavPage):
     self.updatepagestats(data["translatedsourcewords"], data["totalsourcewords"])
     return {"code": languagecode, "icon": "language", "href": href, "title": self.tr_lang(languagename), "data": data}
 
+class LazyStats(object):
+  def __init__(self, project, pofilenames):
+    self._project = project
+    self._pofilenames = pofilenames
+    self._basic = util.undefined
+    self._assign = util.undefined
+    self._units = util.undefined
+  
+  @util.lazy('_basic')
+  def _get_basic(self):
+    return self._project.getquickstats(self._pofilenames)
+  basic = property(_get_basic)
+
+  @util.lazy('_assign')
+  def _get_assign(self):
+    return self._project.combineassignstats(self._pofilenames)
+  assign = property(_get_assign)
+
+  @util.lazy('_units')
+  def _get_units(self):
+    return self._project.combine_unit_stats(self._pofilenames)
+  units = property(_get_units)
+
 class ProjectIndex(pagelayout.PootleNavPage):
   """The main page of a project in a specific language"""
   def __init__(self, project, session, argdict, dirfilter=None):
@@ -332,21 +355,13 @@ class ProjectIndex(pagelayout.PootleNavPage):
       mainstats = ""
       mainicon = "file"
     else:
-      if dirfilter or self.editing or self.showassigns or self.showchecks:
-        # we need the complete stats
-        pofilenames = self.project.browsefiles(dirfilter)
-        projectstats = self.project.combinestats(pofilenames)
-      else:
-        # a common case: plain stats table we can take a shortcut
-        pofilenames = self.project.browsefiles()
-        projectstats = self.project.getquickstats()
+      pofilenames = self.project.browsefiles(dirfilter)
+      projectstats = LazyStats(self.project, pofilenames)
       if self.editing:
         actionlinks = self.getactionlinks("", projectstats, ["editing", "mine", "review", "check", "assign", "goal", "quick", "all", "zip", "sdf"], dirfilter)
-      else: 
+      else:
         actionlinks = self.getactionlinks("", projectstats, ["editing", "goal", "zip", "sdf"])
-      mainstats = self.getitemstats("", projectstats, len(pofilenames))
-      maindata = self.getstats(self.project, projectstats)
-      mainicon = "folder"
+      mainstats = self.getitemstats("", pofilenames, len(pofilenames))
     if self.showgoals:
       childitems = self.getgoalitems(dirfilter)
     else:
@@ -361,7 +376,10 @@ class ProjectIndex(pagelayout.PootleNavPage):
         "language": {"code": self.project.languagecode, "name": self.tr_lang(self.project.languagename)},
         # optional sections, will appear if these values are replaced
         "assign": None, "goals": None, "upload": None,
-        "search": {"title": self.localize("Search")}, "message": message,
+        "search": {"title": self.localize("Search"),
+                   "advanced_title": self.localize("Advanced Search"),
+                   "fields": self.getsearchfields() },
+        "message": message,
         # navigation bar
         "navitems": [{"icon": "folder", "path": navbarpath_dict, "actions": actionlinks, "stats": mainstats}],
         # children
@@ -369,7 +387,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
         # are we in editing mode (otherwise stats)
         "editing": self.editing,
         # stats table headings
-        "statsheadings": self.getstatsheadings(), 
+        "statsheadings": self.getstatsheadings(),
         # general vars
         "session": sessionvars, "instancetitle": instancetitle}
     pagelayout.PootleNavPage.__init__(self, templatename, templatevars, session, bannerheight=80)
@@ -414,15 +432,17 @@ class ProjectIndex(pagelayout.PootleNavPage):
       uploadfile = self.argdict.pop("uploadfile", None)
       # multiple translation file extensions check
       if filter(uploadfile.filename.endswith, extensiontypes):
-       transfiles = True
+        transfiles = True
       else:
-       transfiles = False
+        transfiles = False
       if not uploadfile.filename:
         raise ValueError(self.localize("Cannot upload file, no file attached"))
       if transfiles:
         self.project.uploadfile(self.session, self.dirname, uploadfile.filename, uploadfile.contents, overwrite)
+        self.project.scanpofiles()
       elif uploadfile.filename.endswith(".zip"):
         self.project.uploadarchive(self.session, self.dirname, uploadfile.contents)
+        self.project.scanpofiles()
       else:
         raise ValueError(self.localize("Can only upload PO files and zips of PO files"))
       del self.argdict["doupload"]
@@ -432,6 +452,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
         raise ValueError("cannot update file, no file specified")
       if updatefile.endswith("." + self.project.fileext):
         self.project.updatepofile(self.session, self.dirname, updatefile)
+        self.project.scanpofiles()
       else:
         raise ValueError("can only update files with extension ." + self.project.fileext)
       del self.argdict["doupdate"]
@@ -490,11 +511,11 @@ class ProjectIndex(pagelayout.PootleNavPage):
       if assignwhich == "all":
         pass
       elif assignwhich == "untranslated":
-        search.matchnames = ["fuzzy", "blank"]
+        search.matchnames = ["fuzzy", "untranslated"]
       elif assignwhich == "unassigned":
         search.assignedto = [None]
       elif assignwhich == "unassigneduntranslated":
-        search.matchnames = ["fuzzy", "blank"]
+        search.matchnames = ["fuzzy", "untranslated"]
         search.assignedto = [None]
       else:
         raise ValueError("unexpected assignwhich")
@@ -503,8 +524,8 @@ class ProjectIndex(pagelayout.PootleNavPage):
         self.project.reassignpoitems(self.session, search, goalusers, action)
       del self.argdict["doedituser"]
     # pop arguments we don't want to propogate through inadvertently...
-    for argname in ("assignto", "action", "assignedto", "removefilter", 
-                    "uploadfile", "updatefile", "commitfile", 
+    for argname in ("assignto", "action", "assignedto", "removefilter",
+                    "uploadfile", "updatefile", "commitfile",
                     "newgoal", "editgoal", "editgoalfile", "editgoalname",
                     "newgoaluser", "editfileuser", "edituserwhich"):
       self.argdict.pop(argname, "")
@@ -517,7 +538,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
     elif isinstance(value, int):
       return bool(value)
     elif isinstance(value, (str, unicode)):
-      value = value.lower() 
+      value = value.lower()
       if value.isdigit():
         return bool(int(value))
       if value == "true":
@@ -539,8 +560,8 @@ class ProjectIndex(pagelayout.PootleNavPage):
 
   def getgoalbox(self):
     """adds a box that lets the user add a new goal"""
-    return {"title": self.localize('goals'), 
-            "name-title": self.localize("Enter goal name"), 
+    return {"title": self.localize('goals'),
+            "name-title": self.localize("Enter goal name"),
             "button": self.localize("Add Goal")}
 
   def getuploadbox(self):
@@ -657,7 +678,6 @@ class ProjectIndex(pagelayout.PootleNavPage):
   def getgoalitem(self, goalname, dirfilter, goalusers):
     """returns an item showing a goal entry"""
     pofilenames = self.project.getgoalfiles(goalname, dirfilter, expanddirs=True, includedirs=False)
-    projectstats = self.project.combinestats(pofilenames)
     goal = {"actions": None, "icon": "goal", "isgoal": True, "goal": {"name": goalname}}
     if goalname:
       goal["title"] = goalname
@@ -665,7 +685,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
       goal["title"] = self.localize("Not in a goal")
     goal["href"] = self.makelink("index.html", goal=goalname)
     if pofilenames:
-      actionlinks = self.getactionlinks("", projectstats, linksrequired=["mine", "review", "translate", "zip"], goal=goalname)
+      actionlinks = self.getactionlinks("", LazyStats(self.project, pofilenames), linksrequired=["mine", "review", "translate", "zip"], goal=goalname)
       goal["actions"] = actionlinks
     goaluserslist = []
     if goalusers:
@@ -683,29 +703,28 @@ class ProjectIndex(pagelayout.PootleNavPage):
         goal["goal"]["show_adduser"] = True
         goal["goal"]["otherusers"] = unassignedusers
         goal["goal"]["adduser_title"] = self.localize("Add User")
-    goal["stats"] = self.getitemstats("", projectstats, len(pofilenames))
+    goal["stats"] = self.getitemstats("", pofilenames, len(pofilenames), {'goal': goalname})
+    projectstats = self.project.getquickstats(pofilenames)
     goal["data"] = self.getstats(self.project, projectstats)
     return goal
 
   def getdiritem(self, direntry, linksrequired=None, **newargs):
     """returns an item showing a directory entry"""
     pofilenames = self.project.browsefiles(direntry)
-    if self.showgoals and "goal" in self.argdict:
-      goalfilenames = self.project.getgoalfiles(self.currentgoal, dirfilter=direntry, includedirs=False, expanddirs=True)
-      projectstats = self.project.combinestats(goalfilenames)
-    else:
-      projectstats = self.project.combinestats(pofilenames)
     basename = os.path.basename(direntry)
     browseurl = self.getbrowseurl("%s/" % basename, **newargs)
     diritem = {"href": browseurl, "title": basename, "icon": "folder", "isdir": True}
     basename += "/"
-    actionlinks = self.getactionlinks(basename, projectstats, linksrequired=linksrequired)
+    actionlinks = self.getactionlinks(basename, LazyStats(self.project, pofilenames), linksrequired=linksrequired)
     diritem["actions"] = actionlinks
     if self.showgoals and "goal" in self.argdict:
-      diritem["stats"] = self.getitemstats(basename, projectstats, (len(goalfilenames), len(pofilenames)))
+      goalfilenames = self.project.getgoalfiles(self.currentgoal, dirfilter=direntry, includedirs=False, expanddirs=True)
+      diritem["stats"] = self.getitemstats(basename, goalfilenames, (len(goalfilenames), len(pofilenames)))
+      projectstats = self.project.getquickstats(goalfilenames)
       diritem["data"] = self.getstats(self.projects, projectstats)
     else:
-      diritem["stats"] = self.getitemstats(basename, projectstats, len(pofilenames))
+      diritem["stats"] = self.getitemstats(basename, pofilenames, len(pofilenames))
+      projectstats = self.project.getquickstats(pofilenames)
       diritem["data"] = self.getstats(self.project, projectstats)
     return diritem
 
@@ -717,10 +736,9 @@ class ProjectIndex(pagelayout.PootleNavPage):
       else:
         linksrequired = ["mine", "review", "quick", "all", "po", "xliff", "update", "commit"]
     basename = os.path.basename(fileentry)
-    projectstats = self.project.combinestats([fileentry])
     browseurl = self.getbrowseurl(basename, **newargs)
     fileitem = {"href": browseurl, "title": basename, "icon": "file", "isfile": True}
-    actions = self.getactionlinks(basename, projectstats, linksrequired=linksrequired)
+    actions = self.getactionlinks(basename, LazyStats(self.project, [fileentry]), linksrequired=linksrequired)
     actionlinks = actions["extended"]
     if "po" in linksrequired:
       poname = basename.replace(".xlf", ".po")
@@ -762,8 +780,8 @@ class ProjectIndex(pagelayout.PootleNavPage):
       else:
         actionlink["sep"] = ""
     fileitem["actions"] = actions
-    fileitem["stats"] = self.getitemstats(basename, projectstats, None)
-    fileitem["data"] = self.getstats(self.project, projectstats)
+    fileitem["stats"] = self.getitemstats(basename, [fileentry], None)
+    fileitem["data"] = self.getstats(self.project, self.project.getquickstats([fileentry]))
     return fileitem
 
   def getgoalform(self, basename, goalfile, filegoals):
@@ -786,13 +804,13 @@ class ProjectIndex(pagelayout.PootleNavPage):
       else:
         action = None
       assignstats = self.project.combineassignstats(assignfilenames, action)
-      assignusers = [username.replace("assign-", "", 1) for username in assignstats.iterkeys()]
+      assignusers = list(assignstats.iterkeys())
       useroptions += [username for username in assignusers if username not in useroptions]
       if len(assignusers) > 1:
         multiusers = "multiple"
-      assignwhich = [('all', self.localize("All Strings")), 
+      assignwhich = [('all', self.localize("All Strings")),
                      ('untranslated', self.localize("Untranslated")),
-                     ('unassigned', self.localize('Unassigned')), 
+                     ('unassigned', self.localize('Unassigned')),
                      ('unassigneduntranslated', self.localize("Unassigned and Untranslated"))]
     return {
      "name": goalformname,
@@ -835,7 +853,7 @@ class ProjectIndex(pagelayout.PootleNavPage):
           link = {"href": self.makelink(baseindexlink, **{attrname:1}), "text": showtext}
         link["sep"] = " | "
         actionlinks.append(link)
-    addoptionlink("editing", None, "editing", self.localize("Show Editing Functions"), 
+    addoptionlink("editing", None, "editing", self.localize("Show Editing Functions"),
                                               self.localize("Show Statistics"))
     addoptionlink("track", None, "showtracks", self.localize("Show Tracks"), self.localize("Hide Tracks"))
     # l10n: "Checks" are quality checks that Pootle performs on translations to test for common mistakes
@@ -859,34 +877,37 @@ class ProjectIndex(pagelayout.PootleNavPage):
         minelink = self.localize("Translate My Strings")
       else:
         minelink = self.localize("View My Strings")
-      mystats = projectstats.get("assign-%s" % self.session.username, [])
+      mystats = projectstats.assign.get(self.session.username, [])
       if len(mystats):
         minelink = {"href": self.makelink(baseactionlink, assignedto=self.session.username), "text": minelink}
       else:
         minelink = {"title": self.localize("No strings assigned to you"), "text": minelink}
       actionlinks.append(minelink)
       if "quick" in linksrequired and "translate" in self.rights:
-        mytranslatedstats = [statsitem for statsitem in mystats if statsitem in projectstats.get("translated", [])]
+        if len(mystats) > 0: # A little shortcut to avoid the call to projectstats.units if we don't have anything assigned
+          mytranslatedstats = [statsitem for statsitem in mystats if statsitem in projectstats.units.get("translated", [])]
+        else:
+          mytranslatedstats = []
         quickminelink = self.localize("Quick Translate My Strings")
         if len(mytranslatedstats) < len(mystats):
-          quickminelink = {"href": self.makelink(baseactionlink, assignedto=self.session.username, fuzzy=1, blank=1), "text": quickminelink}
+          quickminelink = {"href": self.makelink(baseactionlink, assignedto=self.session.username, fuzzy=1, untranslated=1), "text": quickminelink}
         else:
           quickminelink = {"title": self.localize("No untranslated strings assigned to you"), "text": quickminelink}
         actionlinks.append(quickminelink)
-    if "review" in linksrequired and projectstats.get("has-suggestion", []):
+    if "review" in linksrequired and projectstats.units.get("check-hassuggestion", []):
       if "review" in self.rights:
         reviewlink = self.localize("Review Suggestions")
       else:
         reviewlink = self.localize("View Suggestions")
-      reviewlink = {"href": self.makelink(baseactionlink, review=1, **{"has-suggestion": 1}), "text": reviewlink}
+      reviewlink = {"href": self.makelink(baseactionlink, review=1, **{"hassuggestion": 1}), "text": reviewlink}
       actionlinks.append(reviewlink)
     if "quick" in linksrequired:
       if "translate" in self.rights:
         quicklink = self.localize("Quick Translate")
       else:
         quicklink = self.localize("View Untranslated")
-      if len(projectstats.get("translated", [])) < len(projectstats.get("total", [])):
-        quicklink = {"href": self.makelink(baseactionlink, fuzzy=1, blank=1), "text": quicklink}
+      if projectstats.basic.get("translated", 0) < projectstats.basic.get("total", 0):
+        quicklink = {"href": self.makelink(baseactionlink, fuzzy=1, untranslated=1), "text": quicklink}
       else:
         quicklink = {"title": self.localize("No untranslated items"), "text": quicklink}
       actionlinks.append(quicklink)
@@ -928,17 +949,16 @@ class ProjectIndex(pagelayout.PootleNavPage):
       actions["basic"][-1]["sep"] = ""
     return actions
 
-  def getitemstats(self, basename, projectstats, numfiles):
+  def getitemstats(self, basename, pofilenames, numfiles, url_opts={}):
     """returns a widget summarizing item statistics"""
-    statssummary = self.describestats(self.project, projectstats, numfiles)
-    stats = {"summary": statssummary, "checks": [], "tracks": [], "assigns": []}
+    stats = {"summary": self.describestats(self.project, self.project.getquickstats(pofilenames), numfiles), "checks": [], "tracks": [], "assigns": []}
     if not basename or basename.endswith("/"):
       linkbase = basename + "translate.html?"
     else:
       linkbase = basename + "?translate=1"
-    if projectstats:
+    if pofilenames:
       if self.showchecks:
-        stats["checks"] = self.getcheckdetails(projectstats, linkbase)
+        stats["checks"] = self.getcheckdetails(pofilenames, linkbase, url_opts)
       if self.showtracks:
         trackfilter = (self.dirfilter or "") + basename
         trackpofilenames = self.project.browsefiles(trackfilter)
@@ -949,15 +969,16 @@ class ProjectIndex(pagelayout.PootleNavPage):
           removelinkbase = "?showassigns=1&removeassigns=1"
         else:
           removelinkbase = "?showassigns=1&removeassigns=1&removefilter=%s" % basename
-        stats["assigns"] = self.getassigndetails(projectstats, linkbase, removelinkbase)
+        stats["assigns"] = self.getassigndetails(pofilenames, linkbase, removelinkbase)
     return stats
 
   def gettrackdetails(self, projecttracks, linkbase):
     """return a list of strings describing the results of tracks"""
     return [trackmessage for trackmessage in projecttracks]
 
-  def getcheckdetails(self, projectstats, linkbase):
+  def getcheckdetails(self, pofilenames, linkbase, url_opts={}):
     """return a list of strings describing the results of checks"""
+    projectstats = self.project.combine_unit_stats(pofilenames)
     total = max(len(projectstats.get("total", [])), 1)
     checklinks = []
     keys = projectstats.keys()
@@ -969,31 +990,29 @@ class ProjectIndex(pagelayout.PootleNavPage):
       checkname = checkname.replace("check-", "", 1)
       if total and checkcount:
         stats = self.nlocalize("%d string (%d%%) failed", "%d strings (%d%%) failed", checkcount, checkcount, (checkcount * 100 / total))
-        checklink = {"href": self.makelink(linkbase, **{checkname:1}), "text": checkname, "stats": stats}
+        url_opts[str(checkname)] = 1
+        checklink = {"href": self.makelink(linkbase, **url_opts), "text": checkname, "stats": stats}
+        del url_opts[str(checkname)]
         checklinks += [checklink]
     return checklinks
 
-  def getassigndetails(self, projectstats, linkbase, removelinkbase):
+  def getassigndetails(self, pofilenames, linkbase, removelinkbase):
     """return a list of strings describing the assigned strings"""
     # TODO: allow setting of action, so goals can only show the appropriate action assigns
-    total = projectstats.get("total", [])
     # quick lookup of what has been translated
-    translated = dict.fromkeys(projectstats.get("translated", []))
-    totalcount = len(total)
-    totalwords = self.project.countwords(total)
+    projectstats = LazyStats(self.project, pofilenames)
+    totalcount = projectstats.basic.get("total", 0)
+    totalwords = projectstats.basic.get("totalsourcewords", 0)
     assignlinks = []
-    keys = projectstats.keys()
+    keys = projectstats.assign.keys()
     keys.sort()
     for assignname in keys:
-      if not assignname.startswith("assign-"):
-        continue
-      assigned = projectstats[assignname]
+      assigned = projectstats.assign[assignname]
       assigncount = len(assigned)
       assignwords = self.project.countwords(assigned)
-      complete = [statsitem for statsitem in assigned if statsitem in translated]
+      complete = [statsitem for statsitem in assigned if statsitem in projectstats.units.get('translated', [])]
       completecount = len(complete)
       completewords = self.project.countwords(complete)
-      assignname = assignname.replace("assign-", "", 1)
       if totalcount and assigncount:
         assignlink = {"href": self.makelink(linkbase, assignedto=assignname), "text": assignname}
         percentassigned = assignwords * 100 / max(totalwords, 1)
