@@ -37,6 +37,7 @@ from Pootle import potree
 from Pootle import pootlefile
 from Pootle import users
 from Pootle import filelocations
+from Pootle import request_cache
 from translate.misc import optrecurse
 # Versioning information
 from Pootle import __version__ as pootleversion
@@ -56,6 +57,14 @@ import re
 import random
 import pprint
 
+def use_request_cache(f):
+    def decorated_f(*args, **kwargs):
+        try:
+            return f(*args, **kwargs)
+        finally:
+            request_cache.reset()
+    return decorated_f
+
 class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
   """the Server that serves the Pootle Pages"""
   def __init__(self, instance, webserver, sessioncache=None, errorhandler=None, loginpageclass=users.LoginPage):
@@ -211,6 +220,7 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
       content += "Disallow: /%s/\n" % langcode
     return content
 
+  @use_request_cache
   def getpage(self, pathwords, session, argdict):
     """return a page that will be sent to the user"""
     #Ensure we get unicode from argdict
@@ -551,7 +561,6 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
           if ancestor is None: continue
           try:
             ancestor_str = str(ancestor)
-            #ancestor_str = kid.et.tostring(ancestor)
           except Exception, e:
             ancestor_str = "(could not convert %s: %s)" % (str(ancestor), str(e))
           xml_traceback.append(ancestor_str)
@@ -567,8 +576,7 @@ class PootleServer(users.OptionalLoginAppServer, templateserver.TemplateServer):
     """bridge to widget code to allow templating to gradually replace it"""
     if kid is not None and hasattr(thepage, "templatename") and hasattr(thepage, "templatevars"):
       # renders using templates rather than the underlying widget class
-      kid.enable_import(path=self.templatedir)
-      #template = kid.Template(os.path.join(self.templatedir, thepage.templatename + ".html")) #self.gettemplate(thepage.templatename)
+      kid.enable_import()
       loadurl = getattr(thepage, "loadurl", None)
       if loadurl is None:
         loadurl = getattr(self, "loadurl", None)
@@ -604,8 +612,8 @@ class PootleOptionParser(simplewebserver.WebOptionParser):
 
 def checkversions():
   """Checks that version dependencies are met"""
-  if not hasattr(toolkitversion, "build") or toolkitversion.build < 12000:
-    raise RuntimeError("requires Translate Toolkit version >= 1.1.  Current installed version is: %s" % toolkitversion.ver)
+  if not hasattr(toolkitversion, "build") or toolkitversion.build < 12001:
+    raise RuntimeError("requires Translate Toolkit version >= 1.2.1.  Current installed version is: %s" % toolkitversion.ver)
 
 def usepsyco(options):
   # options.psyco == None means the default, which is "full", but don't give a warning...
