@@ -28,7 +28,7 @@ from translate.storage import xliff
 from translate.storage import factory
 from translate.filters import checks
 from translate.misc.multistring import multistring
-from Pootle import __version__
+from Pootle import __version__, request_cache
 from Pootle import statistics
 from jToolkit import timecache
 from jToolkit import glock
@@ -471,7 +471,7 @@ def make_class(base_class):
       self.pomtime = pomtime
       self.reset_statistics()
 
-    def savepofile(self, reset_stats=True):
+    def savepofile(self):
       """saves changes to the main file to disk..."""
       output = str(self)
       self.pomtime = self.lockedfile.writecontents(output)
@@ -503,7 +503,6 @@ def make_class(base_class):
       """updates a translation with a new target value"""
       self.pofreshen()
       unit = self.getitem(item)
-      reset_stats = False
 
       if newvalues.has_key("target"):
         unit.target = newvalues["target"]
@@ -524,10 +523,12 @@ def make_class(base_class):
         if userprefs:
           if getattr(userprefs, "name", None) and getattr(userprefs, "email", None):
             headerupdates["Last_Translator"] = "%s <%s>" % (userprefs.name, userprefs.email)
-        # XXX: If we needed to add a header, the index value in item will be one out after
-        # adding the header.
-        # TODO: remove once we force the PO class to always output headers
-        reset_stats = self.header() is None
+        # We are about to insert a header. This changes the structure of the PO file and thus
+        # the total array which lists the editable units. We want to force this array to be
+        # reloaded, so we simply set it to undefined.
+        if self.header() is None:
+            self._total = util.undefined
+            request_cache.reset()
         self.updateheader(add=True, **headerupdates)
         if languageprefs:
           nplurals = getattr(languageprefs, "nplurals", None)
@@ -537,7 +538,7 @@ def make_class(base_class):
       # If we didn't add a header, savepofile doesn't have to reset the stats,
       # since reclassifyunit will do. This gives us a little speed boost for
       # the common case.
-      self.savepofile(reset_stats)
+      self.savepofile()
       self.statistics.reclassifyunit(item)
 
     def getitem(self, item):
