@@ -1,15 +1,15 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# 
+#
 # Copyright 2004-2006 Zuza Software Foundation
-# 
+#
 # This file is part of translate.
 #
 # translate is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
-# 
+#
 # translate is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -25,11 +25,9 @@ from Pootle import projects
 from Pootle import pootlefile
 from Pootle import pagelayout
 from translate.misc import autoencode
-import os
-import re
+from translate.lang import data as langdata
 
-languagere = re.compile("^[a-z]{2,3}([_-][A-Z]{2,3}|)$")
-regionre = re.compile("^[_-][A-Z]{2,3}$")
+import os
 
 class POTree:
   """Manages the tree of projects and languages"""
@@ -93,7 +91,7 @@ class POTree:
             languagecode, countrycode = languagecode.split("_")
             countrycode = countrycode.upper()
             languagecode = "%s_%s" % (languagecode, countrycode)
-          else: 
+          else:
             raise ValueError("Language code must be alphabetic")
         if self.haslanguage(languagecode):
           raise ValueError("Already have language with the code %s" % languagecode)
@@ -473,29 +471,25 @@ class POTree:
 
   def languagematch(self, languagecode, otherlanguagecode):
     """matches a languagecode to another, ignoring regions in the second"""
-    if languagecode is None:
-      return languagere.match(otherlanguagecode)
-    return languagecode == otherlanguagecode or \
-      (otherlanguagecode.startswith(languagecode) and regionre.match(otherlanguagecode[len(languagecode):]))
+    return langdata.languagematch(languagecode, otherlanguagecode)
 
   def getpofiles(self, languagecode, projectcode, poext="po"):
     """returns a list of po files for the project and language"""
+    pofilenames = []
+    prefix = os.curdir + os.sep
 
     def addfiles(podir, dirname, fnames):
       """adds the files to the set of files for this project"""
-      basedirname = dirname.replace(podir, "", 1)
-      while basedirname.startswith(os.sep):
-        basedirname = basedirname.replace(os.sep, "", 1)
-      ponames = []
+      if dirname == os.curdir:
+        basedirname = ""
+      else:
+        basedirname = dirname.replace(prefix, "", 1)
       for fname in fnames:
-        #check that it actually exists (to avoid problems with broken symbolic 
+        # check that it actually exists (to avoid problems with broken symbolic
         # links, for example)
-        if not os.path.exists(os.path.join(dirname, fname)):
-          print "file does not exist:", os.path.join(dirname, fname)
-          continue
+        fpath = os.path.join(basedirname, fname)
         if fname.endswith(os.extsep+poext):
-          ponames.append(fname)
-      pofilenames.extend([os.path.join(basedirname, poname) for poname in ponames])
+          pofilenames.append(fpath)
 
     def addgnufiles(podir, dirname, fnames):
       """adds the files to the set of files for this project"""
@@ -506,12 +500,14 @@ class POTree:
       ponames = [fn for fn in fnames if fn.endswith(ext) and self.languagematch(languagecode, fn[:-len(ext)])]
       pofilenames.extend([os.path.join(basedirname, poname) for poname in ponames])
 
-    pofilenames = []
     podir = self.getpodir(languagecode, projectcode)
     if self.hasgnufiles(podir, languagecode) == "gnu":
       os.path.walk(podir, addgnufiles, podir)
     else:
-      os.path.walk(podir, addfiles, podir)
+      pwd = os.path.abspath(os.curdir)
+      os.chdir(podir)
+      os.path.walk(os.curdir, addfiles, None)
+      os.chdir(pwd)
     return pofilenames
 
   def getdefaultrights(self):
@@ -527,8 +523,10 @@ class POTree:
         translationproject = self.getproject(languagecode, projectcode)
         translationproject.stats = {}
         for pofilename in translationproject.pofilenames:
+          translationproject.indexer # Force indexing to be initialized
           translationproject.getpostats(pofilename)
           translationproject.pofiles[pofilename] = pootlefile.pootlefile(translationproject, pofilename)
+          translationproject.pofiles[pofilename].statistics.getstats()
           print ".",
         print
         self.projectcache = {}
