@@ -14,7 +14,7 @@ def test_init():
     """tests that the index can be initialized"""
     for languagecode, languagename in potree.getlanguages("pootle"):
        translationproject = potree.getproject(languagecode, "pootle")
-       assert hasattr(translationproject, "indexdir")
+       assert translationproject.make_indexer()
 
 def test_search():
     """tests that the index can be initialized"""
@@ -22,7 +22,7 @@ def test_search():
     fail_search = pootlefile.Search(searchtext="Zrogny")
     for languagecode, languagename in potree.getlanguages("pootle"):
        translationproject = potree.getproject(languagecode, "pootle")
-       print translationproject.indexdir
+       print translationproject.make_indexer().location
        pass_search_results = translationproject.searchpoitems("pootle.po", -1, pass_search)
        pass_search_results = [(pofilename, item) for pofilename, item in pass_search_results]
        assert pass_search_results
