@@ -23,7 +23,7 @@ from jToolkit import web
 from jToolkit.web import server
 from jToolkit import mailer
 from jToolkit import prefs
-from Pootle import pagelayout, request_cache
+from Pootle import pagelayout
 from translate.lang import data as langdata
 from translate.lang import factory
 from email.Header import Header
@@ -277,7 +277,6 @@ class OptionalLoginAppServer(server.LoginAppServer):
       else:
         self.initlanguage(req, session)
       page = self.getpage(pathwords, session, argdict)
-      request_cache.reset()
     except Exception, e:
       # Because of the exception, 'session' might not be initialised. So let's
       # play extra safe
